<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
        <source>Passwords do not match</source>
        <translation>密码不一致</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>密码提示对所有人可见，切勿包含具体密码信息</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
        <source>New Password</source>
        <translation>新密码</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <source>Repeat Password</source>
        <translation>重复密码</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
        <source>Password Hint</source>
        <translation>密码提示</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
        <source>Optional</source>
        <translation>选填</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Password cannot be empty</source>
        <translation>密码不能为空</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Password must have at least %1 characters</source>
        <translation>密码长度不能少于%1个字符</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
        <source>Password must be no more than %1 characters</source>
        <translation>密码长度不能超过%1个字符</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密码只能由英文（区分大小写）、数字或特殊符号（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）组成</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>回文字符长度不超过%1位</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>单调性字符不超过%1位</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
        <source>No more than %1 repeating characters please</source>
        <translation>重复字符不超过%1位</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>The password should differ from the username</source>
        <translation>密码不能与用户名一致</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密码必须由大写字母、小写字母、数字、符号（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）三种类型组成</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>密码不得含有连续4个以上的回文字符</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
        <source>Do not use common words and combinations as password</source>
        <translation>密码不能是常见单词及组合</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
        <source>Create a strong password please</source>
        <translation>密码过于简单，请增加密码复杂度</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
        <source>It does not meet password rules</source>
        <translation>密码不符合安全要求</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
        <source>It cannot be empty</source>
        <translation>内容不能为空</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>重设密码将会清除密钥环内已存储的数据</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
        <source>Security Questions</source>
        <translation>安全问题</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
        <source>Reset Password</source>
        <translation>重置密码</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
        <source>Reset Password By UOS ID</source>
        <translation>UOS ID重置密码</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
        <source>Reset</source>
        <translation>重 置</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>重置密码将清空密钥环已保存的数据，并且该用户将重新登录，请注意提前保存文件</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <source>Confirm and Reset</source>
        <translation>确认重置</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>重置密码成功，请使用新密码登录/解锁</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
        <source>Weak</source>
        <translation>强度低</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
        <source>Medium</source>
        <translation>强度中</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
        <source>Strong</source>
        <translation>强度高</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>您出生城市的名称是什么？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>您的母校名称是什么？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>Who do you love the most in this world?</source>
        <translation>您最爱的人是谁？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>您最喜欢的动物是什么？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite song?</source>
        <translation>您最喜欢的音乐是什么？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your nickname?</source>
        <translation>您的绰号是什么？</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
        <source>Wrong answer</source>
        <translation>答案错误</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
        <source>Keep the answer under 30 characters</source>
        <translation>答案请保持在30个字符以内</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
        <source>Phone/Email</source>
        <translation>请输入手机号/邮箱</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
        <source>Get Code</source>
        <translation>获取验证码</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
        <source>Connecting to the Internet...</source>
        <translation>网络连接中...</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
        <source>The user account is not linked to UOS ID</source>
        <translation>当前帐户未绑定UOS ID</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>网络断开，请联网后重试</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
        <source>Required</source>
        <translation>必填</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
        <source>Phone/Email format is incorrect</source>
        <translation>手机号/邮箱格式错误</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>System error</source>
        <translation>系统错误</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation>登录过期，请重新登录UOS ID</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
        <source>Network error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>今日获取验证码次数已达上限</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation>此UOS ID未绑定本地帐户</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
        <source>Resend (%1s)</source>
        <translation>重新获取 (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
        <source>Failed to get the code</source>
        <translation>获取验证码失败</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
        <source>Wrong verification code</source>
        <translation>验证码错误</translation>
    </message>
</context>
</TS>